(function () {
    'use strict';

    angular.module('ngApp').requires.push('leaflet-directive');

    angular
		.module('ngApp')
        .controller('advanceNewsCtrl', advanceNewsController)
        .controller('advanceNewsListCtrl', advanceNewsListController)
        .controller('advanceNewsSearchCtrl', advanceNewsSearchController)
        .controller('advanceNewsCommentCtrl', advanceNewsCommentCtrl)
        .controller('advanceNewsSingleCtrl', advanceNewsSingleCtrl);

    advanceNewsSingleCtrl.$inject = ['$rootScope', '$scope', '$http', '$ionicModal', '$ionicScrollDelegate', '$sce'];
    function advanceNewsSingleCtrl($rootScope, $scope, $http, $ionicModal, $ionicScrollDelegate, $sce) {

        $scope.loading = true;
        $scope.news = {};
        $scope.showSlider = false;
        $scope.$watchCollection(['sl', 'newsId', 'categoryId'], function () {
            loadNewsAndConfigs($scope.newsId, $scope.categoryId);
        });

        /**
         * @param {int} persist
         */
        $scope.userLikeGuard = function (persist) {
            if (persist == null || persist == '' || persist == undefined) {
                persist = false;
            }
            var liked = $scope.likedNews;
            if (persist) {
                $scope.likedNews = true;
            }
            return liked;
        }

        /**
         * @param {int} whatToDo like: 1, dislike: 0
         * @param {int} newsId
         */
        $scope.likeNews = function (whatToDo, newsId) {
            if ($scope.likeIsInProgress || $scope.dislikeIsInProgress) {
                return;
            }

            if ($scope.userLikeGuard(true)) {
                return;
            }

            if (whatToDo == 1) {
                $scope.likeIsInProgress = true;
            } else if (whatToDo == 0) {
                $scope.dislikeIsInProgress = true;
            } else {
                return;
            }
            
            var req = {
                method: 'POST',
                noLoading: true,
                url: url + '/api/v1/widget/post/advance-news/postLikeNews',
                headers: {
                  'Content-Type': 'application/json'
                },
                data: { like_type: whatToDo, news_id: newsId, sl: $scope.sl}
            }

            if (whatToDo == 1) {
                var like = $scope.news.like_count;
                $scope.news.like_count = String((parseInt(like) + 1));
            } else if (whatToDo == 0) {
                var dislike = $scope.news.dislike_count;
                $scope.news.dislike_count = String((parseInt(dislike) + 1));
            }
               
            $http(req).then(function (data) {
                $scope.likeIsInProgress = false;
                $scope.dislikeIsInProgress = false;
            }, function (error) { 
                checkYourInternet();
                $scope.likeIsInProgress = false;
                $scope.dislikeIsInProgress = false;
            });
        }
        
        //Gallery
        $ionicModal.fromTemplateUrl('gallery-modal.html', {
            scope: $scope,
            animation: 'slide-in-up',
            hardwareBackButtonClose: true
        }).then(function($ionicModal) {
            $scope.modal = $ionicModal;
        });
    
        var updated = false;
        $scope.openGalleryModal = function(index) {
            $scope.modal.show();
            $rootScope.openModal = $scope.modal;
            if(!updated) {
                $scope.slider.update();
                updated = true;
            }
            $scope.slider.slideTo(index, 0, $scope.slideChanged(index));
        };
    
        $scope.closeModal = function() {
            $scope.modal.hide();
        };
    
        $scope.zoom = function(index){
            if($scope.inZoom){
                $ionicScrollDelegate.$getByHandle('zoom-pane-' + index).zoomTo(1, true);
                $scope.inZoom = false;
            }else{
                $ionicScrollDelegate.$getByHandle('zoom-pane-' + index).zoomTo(2, true);
                $scope.inZoom = true;
            }
        }
        // Called each time the slide changes
        $scope.slideChanged = function(index) {
            $ionicScrollDelegate.$getByHandle('zoom-pane-' + $scope.slider.previousIndex).zoomTo(1,true);
            $scope.slideIndex = index;
        };

        $scope.$on("$ionicSlides.slideChangeStart", function(event, data){
            $scope.slideChanged($scope.slider.activeIndex)
        });
    
        $scope.$on("$ionicSlides.sliderInitialized", function(event, data){
          // grab an instance of the slider
          $scope.slider = data.slider;
        });

        var loadNewsAndConfigs = function (newsId, newsCategory) {
            fetchNewsAndConfigs(newsId, newsCategory).then(function (response) {
                if (response.status !== 200 || response.data.success === false) {
                    return;
                }
                $scope.news = response.data.payload.news;
                $scope.news.content = $sce.trustAsHtml($scope.news.content);

                if ($scope.news.hasAttributes) {
                    $scope.news.attributes = $scope.news.attributes.map(function (attr) {
                        attr.link = '#nav';
                        attr.link += '/' + $scope.pageSlug;
                        attr.link += '/list';
                        attr.link += '/' + $scope.sl;
                        attr.link += '/' + JSON.stringify(Object.assign(
                            {},
                            { attributes: [attr.id], attributesFilter: true, }
                        ));
                        attr.link += '/' + JSON.stringify({hasSlider: true});
        
                        return attr;
                    });
                }
                $scope.showSlider = response.data.payload.showSlider;
                $scope.map = ($scope.news.latitude && $scope.news.longitude)
                    ? setMapSetting(parseFloat($scope.news.latitude), parseFloat($scope.news.longitude))
                    : false;
                $scope.loading = false;
            });
        };

        var fetchNewsAndConfigs = function (newsId, newsCategory) {
            if (typeof newsCategory === 'undefined' || newsCategory === '')
                newsCategory = 0;
            
            return $http({
                method: 'GET',
                url: url + '/api/v1/widget/route/advance-news/getSingleNewsJson/' + $scope.sl + '/' + newsId + '/' + newsCategory,
            });
        }

        $rootScope.pzzShare = function(event) {
            var titleElem = document.getElementsByClassName('share-title');
            var messageElem = document.getElementsByClassName('share-message');
            var imageElem = document.getElementsByClassName('share-image');
            var urlElem = document.getElementsByClassName('share-url');
            var shareObj = {};
            if (titleElem) {
                titleElem = titleElem[0];
                shareObj.subject = titleElem.textContent;
            }
            if (messageElem) {
                messageElem = messageElem[0];
                shareObj.message = shareObj.subject ?
                    shareObj.subject + "\n" + messageElem.textContent :
                    messageElem.textContent;
            }
            if (imageElem) {
                imageElem = imageElem[0];
                shareObj.files = [imageElem.getAttribute('src')];
            }
            if (urlElem) {
                urlElem = urlElem[0];
                if (urlElem.dataset.shareUrl) {
                    shareObj.url = urlElem.dataset.shareUrl;
                }
            }
            if (isDevice) {
                window.plugins.socialsharing.available(function (isAvailable) {
                    if (isAvailable) {
                        window.plugins.socialsharing.shareWithOptions(
                            shareObj,
                            function () {
                                // callback on succeed
                            },
                            function () {
                                // callback on failed
                            }
                        );
                    }
                })
            } else {
                angular.element(document.body).injector().get('$rootScope').webAppShare(event, shareObj.subject, shareObj.url);
            }
        }

        var setMapSetting = function (lat, lng) {
            return {
                markers: {
                    now: {
                        lat: lat,
                        lng: lng
                    }
                },
                route: false,
                defaults: {
                    scrollWheelZoom: true,
                    doubleClickZoom: false,
                    attributionControl: false,
                    zoomControl: true,
                    zoomControlPosition: 'bottomleft',
                    tileLayer: 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
                },
                center: {
                    lat: lat,
                    lng: lng,
                    zoom: 12,
                }
            };
        }

        $scope.mapsGetDirection = function () {
            window.open('https://www.google.com/maps/dir/?api=1&destination=' + $scope.map.markers.now.lat + ',' + $scope.map.markers.now.lng, '_system');
        }
    }

    advanceNewsCommentCtrl.$inject = ['$scope', '$http', 'gregorianToJulian', '$ionicModal', '$rootScope'];
    function advanceNewsCommentCtrl($scope, $http, gregorianToJulian, $ionicModal, $rootScope) {

        var paged = 2;
        $scope.likeIsInProgress = [];
        $scope.dislikeIsInProgress = [];
        $scope.comment = {};
        $scope.Auth = {};
        $scope.Auth.User = $rootScope.user;
        $scope.likedComments = [];

        var loadNewsSettings = function (newsId) {
            $http({
                method: 'GET',
                url: url + '/api/v1/widget/route/advance-news/getNewsSettings/' + $scope.sl + '/' + newsId,
                headers: {
                    'Content-Type': 'application/json',
                },
                data: {
                    sl: $scope.sl,
                    newsId: newsId,
                },
            })
            .then(function (response) {
                var data = response.data;
                if (!data.success) {
                    return;
                }
                $scope.newsSettings.commentable = data.payload.commentable;
            }, function () {
                checkYourInternet();
            });
        };

        $scope.init = function () {
            $scope.newsSettings = {commentable: false};
            $scope.replyTo = undefined;
        };

        $scope.$watch('news_id', function () {
            if ($scope.news_id != '') {
                $scope.loadComments(false);
                $scope.setUpModal();
                loadNewsSettings($scope.news_id);
            }
        });

        $scope.userIsLogin = function () {
            if (!$scope.Auth.User) {
                return false;
            }
            return $scope.Auth.User.isLogin;
        }

        $scope.submitComment = function () {
            var form = this.fm;
            var comment = $scope.comment;
            if (form.$invalid) {
                return;
            }
            comment.sl = $scope.sl;
            comment.news_id = $scope.news_id;
            comment.parent_id = $scope.replyTo;
            
            var req = {
                method: 'POST',
                noLoading: true,
                url: url + '/api/v1/widget/post/advance-news/postComment',
                headers: {
                    'Content-Type': 'application/json'
                },
                data: comment
            };
               
            $http(req).then(function (response) {
                if (!response.data.success && response.data.error) {
                    showWarning(response.data.error);
                } else {
                    $scope.closeModal();
                    showSuccess(lang('advance-news.comment_success_message'));
                    form.$setPristine();
                    form.$setUntouched();
                    $scope.comment.content = '';
                }
            }, function (error) { 
                checkYourInternet();
            });
        }

        $scope.setUpModal = function () {
            $ionicModal.fromTemplateUrl('my-modal.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function(modal) {
                $scope.modal = modal;
            });
            $scope.openModal = function() {
                $scope.modal.show();
                $rootScope.openModal = $scope.modal;
            };
            $scope.closeModal = function() {
                $scope.modal.hide();
            };
            $scope.openReplyModal = function (commentId) {
                $scope.replyTo = commentId;
                $scope.openModal();
            };
            $scope.openNewModal = function () {
                $scope.replyTo = undefined;
                $scope.openModal();
            };
            // Cleanup the modal when we're done with it!
            $scope.$on('$destroy', function() {
                $scope.modal.remove();
            });
            // Execute action on hide modal
            $scope.$on('modal.hidden', function() {
                // Execute action
            });
            // Execute action on remove modal
            $scope.$on('modal.removed', function() {
                // Execute action
            });
        }

        /**
         * #c31432; 
         * #28a54c;
         * @param {int} whatToDo like: 1, dislike: 0
         */
        $scope.likeComment = function (whatToDo, commentId, index) {
            if ($scope.likeIsInProgress[commentId] || $scope.dislikeIsInProgress[commentId]) {
                return;
            }

            if ($scope.userLikeGuard(commentId, whatToDo, true)) {
                return;
            }

            if (whatToDo == 1) {
                $scope.likeIsInProgress[commentId] = true;
            } else if (whatToDo == 0) {
                $scope.dislikeIsInProgress[commentId] = true;
            } else {
                return;
            }
            
            var req = {
                method: 'POST',
                noLoading: true,
                url: url + '/api/v1/widget/post/advance-news/postLikeComment',
                headers: {
                  'Content-Type': 'application/json'
                },
                data: { like_type: whatToDo, comment_id: commentId, sl: $scope.sl}
            }

            if (whatToDo == 1) {
                var like = $scope.comments[index].like_count;
                $scope.comments[index].like_count = (parseInt(like) + 1).toString();
            } else if (whatToDo == 0) {
                var dislike = $scope.comments[index].dislike_count;
                $scope.comments[index].dislike_count = (parseInt(dislike) + 1).toString();
            }
               
            $http(req).then(function (data) {
                $scope.likeIsInProgress[commentId] = false;
                $scope.dislikeIsInProgress[commentId] = false;
            }, function (error) { 
                checkYourInternet();
                $scope.likeIsInProgress[commentId] = false;
                $scope.dislikeIsInProgress[commentId] = false;
            });
        }

        $scope.userLikeGuard = function (commentId, likeType, persist) {
            if (persist == null || persist == '' || persist == undefined) {
                persist = false;
            }
            var key = commentId + '_' + likeType;
            if ($scope.likedComments.includes(key)) {
                return true;
            }
            if (persist) {
                $scope.likedComments.push(key);
            }
            return false;
        }

        $scope.loadComments = function (Refreshing) {
            if (Refreshing) {
                paged = 2;
            }

            $scope.loading = true;

            $http({
                method: 'JSONP',
				noLoading: true,
				url: url + '/api/v1/widget/route/advance-news/getComments/' + $scope.sl + '/' + $scope.news_id + '?_jsonp=JSON_CALLBACK'
			})
			.success(function (data) {
                if (!data.success) {
                    return;
                }
                
                data.payload.comments.forEach(function (element) {
					element.date_persian = gregorianToJulian(element.created_at).toString();
                });
                
                $scope.comments = data.payload.comments;
				$scope.moreItems = true;
				$scope.loading = false;
			})
			.error(function () {
				checkYourInternet();
				$scope.$broadcast('scroll.refreshComplete');
				$scope.loading = false;
			});
        };

        // Load more (infinite scroll)
        $scope.loadMore = function () {
            if (!$scope.moreItems) {
                return;
            }

            var pg = paged++;
            var apiurl = url + 
                         '/api/v1/widget/route/advance-news/getComments/' + 
                         $scope.sl + '/' + 
                         $scope.news_id + '?page=' + pg + '&per_page=' + 5

            $http({
                noLoading: true,
                url: apiurl
            })
            .success(function (data) {
                if (!data.success) {
                    $scope.moreItems = false;
                    return;
                }

                data = data.payload.comments;
                
                data.forEach(function (element) {
					element.date_persian = gregorianToJulian(element.created_at).toString();
                });

                angular.forEach(data, function (value) {
                    $scope.comments.push(value);
                });

                if (data.length <= 0) {
                    $scope.moreItems = false;
                }

                $scope.$broadcast('scroll.infiniteScrollComplete');
                $scope.$broadcast('scroll.resize');

            }).
            error(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $scope.loading = false;
            });
        };
    }

    advanceNewsSearchController.$inject = ['$scope', '$http'];
    function advanceNewsSearchController($scope, $http) {
        
        $scope.$watch('sl', function () {
            loadPageContents();
        });

        $scope.checkFilters = function () {
            $scope.$broadcast(
                'advance-news:filters-changed'
            );
        };

        $scope.toggleFilterCategories = function (id, attrs) {
            if ($scope.searchFilters.categories.includes(id)) {
                $scope.searchFilters.categories =
                    $scope.searchFilters.categories.filter(function (v) {
                        return v != id;
                    });
            } else {
                $scope.searchFilters.categories.push(id);
                $scope.selectAllAttributes(attrs);
            }
            $scope.checkFilters();
        };

        $scope.selectAllCategories = function () {
            $scope.searchFilters.categories = [];
            $scope.categories.forEach(function (c) {
                $scope.searchFilters.categories.push(c.id);
                $scope.selectAllAttributes(c.attrs);
            });
            $scope.checkFilters();
        };

        $scope.removeAllCategories = function () {
            $scope.searchFilters.categories = [];
            $scope.searchFilters.attributes = [];
            $scope.checkFilters();
        };

        $scope.toggleFilterAttributes = function (id) {
            if ($scope.searchFilters.attributes.includes(id)) {
                $scope.searchFilters.attributes =
                    $scope.searchFilters.attributes.filter(function (v) {
                        return v != id;
                    });
            } else {
                $scope.searchFilters.attributes.push(id);
            }
            $scope.checkFilters();
        };

        $scope.selectAllAttributes = function (attributes) {
            if (!attributes || attributes.length == 0) {
                return;
            }
            attributes.forEach(function (a) {
                if (!$scope.searchFilters.attributes.includes(a.id)) {
                    $scope.searchFilters.attributes.push(a.id);
                }
            });
            $scope.checkFilters();
        };

        $scope.removeAllAttributes = function (attributes) {
            var len = attributes.length;
            $scope.searchFilters.attributes = 
            $scope.searchFilters.attributes.filter(function (item) {
                var r = true;
                for (var i = 0; i < len; i++) {
                    if (item == attributes[i].id) {
                        r = false;
                        break;
                    }
                }
                return r;
            });
            $scope.checkFilters();
        };

        $scope.$on(
            'advance-news:filters-changed',
            function (e, data) {
                $scope.searchFilters.attributesFilter =
                    $scope.searchFilters.attributes.length > 0;
                $scope.searchFilters.categoriesFilter =
                    $scope.searchFilters.categories.length > 0;
            }
        );

        $scope.init = function (sl, pageSlug) {
            $scope.news = [];
            $scope.searchFilters = {
                title: true,
                content: true,
                tag: true,
                attributesFilter: false,
                categoriesFilter: false,
                attributes: [],
                categories: [],
            };
            $scope.noMoreItemsAvailable = true;
            $scope.infiniteScrollLoading = false;
            $scope.sl = sl;
            $scope.pageSlug = pageSlug;
        };

        $scope.search = function (sl) {
            window.location.href = '#nav/' + $scope.pageSlug + '/list/' + $scope.sl + '/' + JSON.stringify($scope.searchFilters) + '/{}';
        };

        var loadPageContents = function () {
            return $http({
                url: url + '/api/v1/widget/get/advance-news/getContentsForSearchPage',
                method: 'GET',
                params: {
                    sl: $scope.sl,
                }
            }).then(function (response) {
                if (Boolean(response.data.success) === false) return;
                $scope.categories = response.data.payload.categories;
            }, function (response) {
                $scope.categories = [];
            });
        };
    }
    
    advanceNewsController.$inject = ['$scope', '$http', '$timeout'];
    function advanceNewsController($scope, $http, $timeout) {

        var getCategoriesListByParent = function (parentId) {
            if (typeof parentId === 'undefined') {
                parentId = 0;
            }
            var apiUrl = url;
            apiUrl += '/api/v1/widget/route/advance-news/getCategoriesListByParent';
            apiUrl += '/' + $scope.sl;
            apiUrl += '/' + parentId;
            return $http({
                url: apiUrl,
                method: 'GET'
            }).then(function (response) {
                if (response.status !== 200 || response.data.success !== true) {
                    $scope.categoriesList = [];
                } else {
                    var data = response.data.payload;
                    data.categories = generateCategoriesListLinks(data.categories);
                    $scope.categoriesList = data.categories;
                    $scope.layout = data.layout;
                }
                $scope.collapsed = true;
            }, function () {
                $scope.categoriesList = [];
                $scope.collapsed = true;
            });
        };

        $scope.sliderdata = {};
        var getHomepageSlider = function () {
            $http({
                url: url + '/api/v1/widget/route/advance-news/getHomepageSlider/' + $scope.sl,
                method: 'GET'
            }).then(function (response) {
                $scope.sliderLoading = true;
                $scope.slider = {items: [], options: $scope.sliderOptions};
                if (response.status !== 200 || response.data.success !== true) {
                    $scope.sliderLoading = false;
                } else {
                    var data = response.data.payload;
                    data.slider.items = JSON.parse(JSON.stringify(data.slider.items.filter(function (slide) {
                        return slide.image ? slide.image.trim() !== '' : false;
                    })));
                    $scope.slider = data.slider;
                    $scope.sliderLoading = false;
                }
            }, function () {
                $scope.sliderLoading = false;
            });
        };

        var generateCategoriesListLinks = function (categoriesList) {
            return categoriesList.map(function (category) {
                category.link = '#nav';
                if (parseInt(category.childCount) === 0) {
                    category.link += '/' + $scope.pageSlug;
                    category.link += '/list';
                    category.link += '/' + $scope.sl;
                    category.link += '/{"categories":[' + category.id + '],"categoriesFilter":true}';
                    category.link += '/{"hasSlider": true}';
                } else {
                    category.link += '/widget/advance-news/getCategoryIndex';
                    category.link += '/' + $scope.sl;
                    category.link += '/' + category.id;
                }

                return category;
            });
        };

        var loadCategorySlider = function (categoryId) {
            return $http({
                method: 'GET',
                url: '/api/v1/widget/get/advance-news/getCategorySlider',
                params: {
                    sl: $scope.sl,
                    categoryId: categoryId,
                }
            })
            .success(function (data, status) {
                if (status === 200 && Boolean(data.success) === true) {
                    $scope.slider = data.payload.slider;
                } else {
                    $scope.slider = {items: [], options: $scope.sliderOptions};
                }
                $scope.sliderLoading = false;
            })
            .error(function () {
                $scope.sliderLoading = false;
            });
        };

        var loadSlider = function () {
            if (parseInt($scope.categoryParentId) === 0) {
                getHomepageSlider();
            } else {
                loadCategorySlider($scope.categoryParentId);
            }
        }

        $scope.getCategoriesListByParent = function (parentId) {
            getCategoriesListByParent(parentId);
        };

        $scope.$watchGroup(['sl', 'pageSlug', 'categoryParentId'], function () {
            $scope.sliderOptions = {
                loop: true, 
                speed: 400, 
                autoplay: 7000, 
                effect: 'slide'
            };
            getCategoriesListByParent($scope.categoryParentId);
            loadSlider();
        });

        $scope.init = function (sl) {
            $scope.layout = {
                catsCount: 0,
                iterateItems: [],
                chunkSize: 16,
            };
            $scope.sl = sl;
        };
    }

    advanceNewsListController.$inject = ['$scope', '$http', '$stateParams', '$ionicModal', '$location', '$ionicScrollDelegate'];
    function advanceNewsListController($scope, $http, $stateParams, $ionicModal, $location, $ionicScrollDelegate) {
        $scope.init = init;
        $scope.showAttrsFilterModal = showAttrsFilterModal;
        $scope.hideAttrsFilterModal = hideAttrsFilterModal;
        $scope.updateAttrsFilter = updateAttrsFilter;
        $scope.removeFilters = removeFilters;
        $scope.selectParentAttr = selectParentAttr;

        function init(sl, pageSlug, searchFilters, searchConfig) {
            if ($stateParams.searchFilters) {
                $stateParams.searchFilters = JSON.parse($stateParams.searchFilters);
                $stateParams.config = JSON.parse($stateParams.config);
            } else if (typeof searchFilters !== 'undefined') {
                $stateParams.searchFilters = searchFilters;
                if (typeof searchConfig !== 'undefined') {
                    $stateParams.config = searchConfig;
                }
            }
            $scope.data = {};
            $scope.news
            = $scope.data.slider
            = $scope.selectedAttributes
            = [];
            $scope.hasSlider
            = $scope.infiniteScrollLoading
            = $scope.noMoreItemsAvailable
            = false;
            $scope.sliderLoading = true;
            $scope.sl = sl;
            $scope.pageSlug = pageSlug;
            $scope.attrsFilterLink
            = $scope.originalLink = '';
            $scope.selectedParentAttr = 0;
            attrsFilterModalSetup();
        }

        function selectParentAttr(attr) {
            $scope.selectedParentAttr = attr;
        }

        function attrsFilterModalSetup() {
            $ionicModal.fromTemplateUrl('attrs-filter-modal.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function(modal) {
                $scope.attrsFilterModal = modal;
            });
        }

        function generateAttrsFilterLink(attrs) {
            if (typeof attrs !== 'object' || attrs == null) {
                attrs = [];
            }
            if (typeof $stateParams.searchFilters === 'string') {
                $stateParams.searchFilters = JSON.parse($stateParams.searchFilters);
            }
            if (typeof $stateParams.config === 'string') {
                $stateParams.config = JSON.parse($stateParams.config);
            }
            var newFilters = JSON.parse(JSON.stringify($stateParams.searchFilters));
            var attributesFilter = { attributes: attrs, attributesFilter: attrs.length > 0, };
            var searchFilters = JSON.stringify(Object.assign(
                newFilters,
                attributesFilter
            ));
            return (
                '#nav'
                + '/'
                + $scope.pageSlug
                + '/list'
                + '/'
                + $scope.sl
                + '/'
                + searchFilters
                + '/' + JSON.stringify(Object.assign(
                    {},
                    $stateParams.config
                ))
            );
        }

        function showAttrsFilterModal() {
            if ($scope.attributes && $scope.attributes.length > 0) {
                selectParentAttr($scope.attributes[0]);
            }
            $scope.attrsFilterModal.show();
        }

        function hideAttrsFilterModal() {
            $scope.attrsFilterModal.hide();
        }

        // Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function() {
            $scope.attrsFilterModal.remove();
        });
        // Execute action on hide modal
        $scope.$on('attrsFilterModal.hidden', function() {
            // Execute action
        });
        // Execute action on remove modal
        $scope.$on('attrsFilterModal.removed', function() {
            // Execute action
        });

        function removeFilters() {
            $scope.selectedAttributes = [];
            hideAttrsFilterModal();
        }

        function updateAttrsFilter(attr) {
            var index = $scope.selectedAttributes.indexOf(attr.id);
            if (index >= 0) {
                $scope.selectedAttributes.splice(index, 1);
                return;
            }
            $scope.selectedAttributes.push(attr.id);
        }

        $scope.$watch('selectedAttributes', function () {
            $scope.attrsFilterLink = generateAttrsFilterLink($scope.selectedAttributes);
        }, true);

        $scope.$watch('$stateParams.searchFilters', function () {
            if (typeof $stateParams.searchFilters.attributes === 'object'
                && $stateParams.searchFilters.attributes !== null) {
                $scope.selectedAttributes = $stateParams.searchFilters.attributes;
            }
            $scope.originalLink = generateAttrsFilterLink([]);
        });

        $scope.$watchGroup(['sl', 'pageSlug'], function () {
            $scope.hasSlider
                = typeof $stateParams.config.hasSlider !== 'undefined'
                    ? $stateParams.config.hasSlider : false;
            loadNews();
            loadSlider();
        });

        $scope.doRefresh = function () {
            loadNews(true).then(function () {
                $scope.$broadcast('scroll.refreshComplete');
            });
        };

        $scope.loadMore = function () {
            if ($scope.noMoreItemsAvailable === true) {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                return;
            }
            $scope.infiniteScrollLoading = true;
            if (typeof $stateParams.searchFilters === 'string')
                $stateParams.searchFilters = JSON.parse($stateParams.searchFilters);
            if (typeof $stateParams.config === 'string')
                $stateParams.config = JSON.parse($stateParams.config);
            
            $stateParams.searchFilters.start = $scope.news.length;
            return fetchNews($stateParams.searchFilters, $stateParams.config)
            .then(function (response) {
                var data = response.data;
                if (response.status === 200 && data.success === true) {
                    $scope.news = $scope.news.concat(data.payload.news);
                } else {
                    data.payload.news = [];
                }
                $scope.infiniteScrollLoading = false;
                $scope.$broadcast('scroll.infiniteScrollComplete');

                $scope.noMoreItemsAvailable = data.payload.news.length < 6;
                horizontalScrollFix();
            });
        };

        var loadNews = function (refresh) {
            if (typeof refresh === 'undefined' || !refresh)
                $scope.loading = true;
            if (typeof refresh !== 'undefined' && refresh) {
                if ($stateParams.searchFilters !== Object($stateParams.searchFilters)) {
                    $stateParams.searchFilters = JSON.parse($stateParams.searchFilters);
                }
                $stateParams.searchFilters.start = 0;
                $scope.noMoreItemsAvailable = false;
            }
            return fetchNews($stateParams.searchFilters, $stateParams.config)
            .then(function (response) {
                var data = response.data;
                if (response.status !== 200 || data.payload.success === false) {
                    $scope.news = [];
                    $scope.attributes = [];
                    $scope.noMoreItemsAvailable = true;
                } else {
                    $scope.news = data.payload.news;
                    if (data.payload.news.length < 6) {
                        $scope.noMoreItemsAvailable = true;
                    }
                    $scope.hasSlider = data.payload.hasSlider;
                    $scope.attributes = data.payload.attributes;
                }
            })
            .then(function () {
                $scope.loading = false;
                horizontalScrollFix();
            });
        };

        var fetchNews = function (searchFilters, config) {
            return $http({
                method: 'GET',
                url: url + '/api/v1/widget/get/advance-news/getNewsByFilter',
                params: {
                    searchFilters: searchFilters,
                    config: config,
                    sl: $scope.sl,
                }
            });
        }

        var loadSlider = function () {
            if (typeof $stateParams.searchFilters === 'undefined') return;
            if (typeof $stateParams.searchFilters.categories === 'undefined') return;
            if ($scope.hasSlider === false || $stateParams.searchFilters.categories.length < 1) return;
            return $http({
                method: 'GET',
                url: '/api/v1/widget/get/advance-news/getCategorySlider',
                params: {
                    sl: $scope.sl,
                    categoryId: $stateParams.searchFilters.categories[0],
                }
            })
            .success(function (data, status) {
                if (status === 200 && Boolean(data.success) === true) {
                    $scope.data.slider = data.payload.slider;
                } else {
                    $scope.data.slider = {items: [], options: {}};
                }
                $scope.sliderLoading = false;
            })
            .error(function () {
                $scope.sliderLoading = false;
            });
        };

        var horizontalScrollFix = function () {
            setTimeout(function () {
                $ionicScrollDelegate.$getByHandle('attributes').scrollTo(2000, 0, false);
            }, 100);
        };
    }
})();


/*fix horizontal Scroller*/
(function(){var t=function(){return function(t,e){return{restrict:"A",link:function(o,n,r){var a=r.horizontalScrollFix,i=r.delegateHandle,c=function(t){return t.touches&&(t.touches.length?t.touches:[{pageX:t.pageX,pageY:t.pageY}])},l=function(){var o,n;o=e.$getByHandle(a).getScrollView(),(n=e.$getByHandle(i).getScrollView()).__container.removeEventListener("touchstart",n.touchStart),n.touchStart=function(e){var r;n.startCoordinates=ionic.tap.pointerCoord(e),ionic.tap.ignoreScrollStart(e)||(n.__isDown=!0,ionic.tap.containsOrIsTextInput(e.target)||"SELECT"===e.target.tagName?n.__hasStarted=!1:(n.__isSelectable=!0,n.__enableScrollY=!0,n.__hasStarted=!0,n.doTouchStart(c(e),e.timeStamp),r=o.__scrollTop,t(function(){var t,e;return e=r-o.__scrollTop,n.__isDragging&&e<2&&e>-2?(o.__isTracking=!1,o.doTouchEnd(),t=!1,o.scrollTo(0,r,t)):n.doTouchEnd()},100)))},n.__container.addEventListener("touchstart",n.touchStart)};t(function(){l()})}}}}();angular.module("ngApp").directive("horizontalScrollFix",["$timeout","$ionicScrollDelegate",t])}).call(this);
