/**
 * @file tapsell widget controller
 * @author Hussein Arian <hossein@puzzley.ir>
 * @version 2.0.0
 */

document.addEventListener("deviceready", function () {
	// wait to app initialaize complete
	setTimeout(function () {
		if ($show_ad) {
			console.log('deviceready:tapsell_controller');
			$widgets.functions.tapsell = tapsell_controller();

			if ($widgets.data.tapsell.enable.banner) {
				$widgets.functions.tapsell.banner.add();
			}

			if ($widgets.data.tapsell.enable.interstitial) {
				var interstitialTime = $widgets.data.tapsell.interval.interstitial * 1000 * 60;
				setTimeout(function(){
					setInterval(function () {
						// for disable show ad on runtime
						if ($widgets.data.tapsell.enable.interstitial) {
							$widgets.functions.tapsell.fullscreen.prepare('interstitial');
							$widgets.data.tapsell.showfullscreen = true;
						}
					}, interstitialTime);
				}, interstitialTime);
			}

			if ($widgets.data.tapsell.enable.rewardvideo) {
				var rewardvideoTime = $widgets.data.tapsell.interval.rewardvideo * 1000 * 60;
				setTimeout(function () {
					setInterval(function () {
						if ($widgets.data.tapsell.enable.rewardvideo) {
							$widgets.functions.tapsell.fullscreen.prepare('rewardvideo');
							$widgets.data.tapsell.showfullscreen = true;
						}
					}, rewardvideoTime);
				}, rewardvideoTime);
			}

		}
	}, 3000);
});

var tapsell_controller = function () {
	'use strict';

	var widget_data = $widgets.data.tapsell;
	var plugin = Tapsell;
	var config = {
		banner: {
			position: plugin.AD_POSITION.BOTTOM_CENTER,
			size: plugin.AD_SIZE.BANNER_320x50
		},
		fullscreen: {
			cashe: plugin.CACHE_TYPE.CACHED,
			backDisabled: false,
			immersiveMode: false,
			rotationMode: plugin.AD_ROTATION.UNLOCKED,
			showDialog: false
		},
		rewardvideo: {
			cashe: plugin.CACHE_TYPE.CACHED,
			backDisabled: false,
			immersiveMode: false,
			rotationMode: plugin.AD_ROTATION.UNLOCKED,
			showDialog: false
		}
	};
	
	plugin.initialize(widget_data.key);
	setlistener();

	var banner = {
		add: function () {
			plugin.createBanner(widget_data.zoneid.banner, config.banner.position, config.banner.size);
			console.log('banner: add');
		},
		show: function () {
			plugin.showBanner();
			this.onShowAdBanner();
		},
		hide: function () {
			plugin.hideBanner();
			this.hideAdBanner();
		},
		remove: function () {
			plugin.removeBanner();
			this.hideAdBanner();
		},
		onNoAdAvailable: function () {
			this.hideAdBanner();
			console.log('banner: onNoAdAvailable');
		},
		onNoNetwork: function () {
			this.hideAdBanner();
			console.log('banner: onNoNetwork');
		},
		onError: function (data) {
			console.error(data);
			console.log('banner: onError');
			this.hideAdBanner();
		},
		onRequestFilled: function () {
			this.show();
			console.log('banner: onRequestFilled');
		},
		onHideBannerView: function () {
			console.log('banner: onHideBannerView');
			this.hideAdBanner();
		},
		hideAdBanner: function () {
			document.getElementsByTagName('html')[0].classList.remove('banner-ad-active');
			console.log('banner: hideAdBanner');
		},
		onShowAdBanner: function () {
			document.getElementsByTagName('html')[0].classList.add('banner-ad-active');
			console.log('banner: onShowAdBanner');
		}
	};

	var fullscreen = {
		prepare: function (type) {
			console.log('fullscreen: prepare type ' + type);
			plugin.requestAd(widget_data.zoneid[type], config.fullscreen.cashe);
		},
		show: function () {
			console.log('fullscreen: show');
			if ($widgets.data.tapsell.showfullscreen === true) {
				plugin.showAd(
					config.fullscreen.backDisabled,
					config.fullscreen.immersiveMode,
					config.fullscreen.rotationMode,
					config.fullscreen.showDialog
				);
			}
			$widgets.data.tapsell.showfullscreen = false;
		},
		onAdAvailable: function () {
			this.show();
			console.log('fullscreen: onAdAvailable');
		},
		onNoAdAvailable: function () {
			console.log('fullscreen: onNoAdAvailable');
		},
		onNoNetwork: function () {
			console.log('fullscreen: onNoNetwork');
		},
		onError: function (data) {
			console.error(data.message);
			console.log('fullscreen: onError');
		},
		onExpiring: function () {
			console.log('fullscreen: onExpiring');
		},
		onRequestFilled: function () {
			console.log('fullscreen: onRequestFilled');
		},
		onAdShowFinished: function (data) {
			console.log(data);
			console.log('fullscreen: onAdShowFinished');
		},
		onClosed: function () {
			console.log('fullscreen: onClosed');
		},
		onOpened: function () {
			console.log('fullscreen: onOpened');
		}
	};

	function dissableAd() {
		banner.remove();
		widget_data.enable = {
			banner: false,
			interstitial: false,
			rewardvideo: false
		};
	}

	function eventHandeler(eventName, e) {
		if (typeof e.originalEvent !== 'undefined') e = e.originalEvent;
		var data = e.detail || e.data || e;

		if (typeof data == "object" && typeof data.adType != "undefined") {
			if (data.adType == 'banner') {
				if (typeof banner[eventName] == 'function') {
					banner[eventName](data);
				} else {
					console.error(eventName + ' not in banner');
				}
			} else if (data.adType == 'nonBanner') {
				if (typeof fullscreen[eventName] == 'function') {
					fullscreen[eventName](data);
				} else {
					console.error(eventName + ' not in fullscreen');
				}
			}
		}
	}

	function setlistener() {
		document.addEventListener("removeAd", dissableAd);
		document.addEventListener('onAdShowFinished', function (e) {
			eventHandeler('onAdShowFinished', e);
		});
		document.addEventListener('onAdAvailable', function (e) {
			eventHandeler('onAdAvailable', e);
		});
		document.addEventListener('onNoAdAvailable', function (e) {
			eventHandeler('onNoAdAvailable', e);
		});
		document.addEventListener('onError', function (e) {
			eventHandeler('onError', e);
		});
		document.addEventListener('onNoNetwork', function (e) {
			eventHandeler('onNoNetwork', e);
		});
		document.addEventListener('onExpiring', function (e) {
			eventHandeler('onExpiring', e);
		});
		document.addEventListener('onOpened', function (e) {
			eventHandeler('onOpened', e);
		});
		document.addEventListener('onClosed', function (e) {
			eventHandeler('onClosed', e);
		});
		document.addEventListener('onRequestFilled', function (e) {
			eventHandeler('onRequestFilled', e);
		});
		document.addEventListener('onHideBannerView', function (e) {
			eventHandeler('onHideBannerView', e);
		});
		document.addEventListener('onHideBannerView', function (e) {
			eventHandeler('onHideBannerView', e);
		});
	}

	return {
		banner: banner,
		fullscreen: fullscreen
	}
}